@@ -9,7 +9,7 @@ Various utilities for `aiohttp <https://aiohttp.rtfd.io/>`_ and other
 """
 
 from contextlib import contextmanager
-from typing import Iterator, Optional, Union
+from typing import Iterator, Union
 from urllib.parse import urlparse
 
 from aiohttp import web
@@ -28,9 +28,9 @@ class AddResourceFunc(Protocol):
     def __call__(
         self,
         url: str,
-        get: Handler = None,
+        get: Union[Handler, None] = None,
         *,
-        name: str = None,
+        name: Union[str, None] = None,
         **kwargs: Handler,
     ) -> web.Resource:
         ...
@@ -38,7 +38,9 @@ class AddResourceFunc(Protocol):
 
 @contextmanager
 def add_resource_context(
-    router: web.UrlDispatcher, url_prefix: str = None, name_prefix: str = None
+    router: web.UrlDispatcher,
+    url_prefix: Union[str, None] = None,
+    name_prefix: Union[str, None] = None,
 ) -> Iterator[AddResourceFunc]:
     """Context manager for adding resources for given router.
 
@@ -65,7 +67,11 @@ def add_resource_context(
     """
 
     def add_resource(
-        url: str, get: Handler = None, *, name: str = None, **kwargs: Handler
+        url: str,
+        get: Union[Handler, None] = None,
+        *,
+        name: Union[str, None] = None,
+        **kwargs: Handler,
     ) -> web.Resource:
         """Inner function to create resource and add necessary routes to it.
 
@@ -115,7 +121,7 @@ def is_xhr_request(request: web.Request) -> bool:
 
     :param request: Request instance.
     """
-    value: Optional[str] = request.headers.get("X-Requested-With")
+    value: Union[str, None] = request.headers.get("X-Requested-With")
     return value == "XMLHttpRequest"
 
 
@@ -134,7 +140,7 @@ def parse_aioredis_url(url: str) -> DictStrAny:
     """
     parts = urlparse(url)
 
-    db: Optional[Union[str, int]] = parts.path[1:] or None
+    db: Union[str, int, None] = parts.path[1:] or None
     if db:
         db = int(db)
 
