@@ -15,7 +15,7 @@ from typing import Any, Callable, Dict, Mapping, Type, TypeVar, Union
 try:
     from typing import Literal, Protocol, TypedDict
 except ImportError:
-    from typing_extensions import Literal, Protocol, TypedDict  # type: ignore
+    from typing_extensions import Literal, Protocol, TypedDict  # type: ignore[misc]
 
 from aiohttp import web
 from aiohttp_middlewares.annotations import Handler
