@@ -2,7 +2,7 @@ import logging
 import re
 from contextlib import contextmanager
 from contextvars import ContextVar
-from typing import Any, Dict, Iterator, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterator, List, Tuple, Union
 
 import attr
 from jsonschema.exceptions import ValidationError as JsonSchemaValidationError
@@ -68,7 +68,10 @@ class OpenAPIError(Exception):
     status = 500
 
     def __init__(
-        self, message: str = None, *, headers: MappingStrStr = None
+        self,
+        message: Union[str, None] = None,
+        *,
+        headers: Union[MappingStrStr, None] = None,
     ) -> None:
         super().__init__(message or self.default_message)
         self.headers = headers or self.default_headers
@@ -137,8 +140,8 @@ class ObjectDoesNotExist(OpenAPIError):
         self,
         label: str = OBJECT_LABEL,
         *,
-        message: str = None,
-        headers: MappingStrStr = None,
+        message: Union[str, None] = None,
+        headers: Union[MappingStrStr, None] = None,
     ) -> None:
         super().__init__(
             message or ERROR_NOT_FOUND_TEMPLATE.format(label=label),
@@ -188,8 +191,8 @@ class ValidationError(OpenAPIError):
     def __init__(
         self,
         *,
-        message: str = None,
-        errors: List[ValidationErrorItem] = None,
+        message: Union[str, None] = None,
+        errors: Union[List[ValidationErrorItem], None] = None,
     ) -> None:
         super().__init__(message or self.default_message)
 
@@ -231,8 +234,8 @@ class ValidationError(OpenAPIError):
         return self
 
     @classmethod
-    def from_dict(  # type: ignore
-        cls, data: DictPathItemAny = None, **kwargs: Any
+    def from_dict(  # type: ignore[misc]
+        cls, data: Union[DictPathItemAny, None] = None, **kwargs: Any
     ) -> "ValidationError":
         if data and kwargs:
             raise ValueError(
@@ -255,11 +258,11 @@ class ValidationError(OpenAPIError):
         return cls(errors=errors)
 
     @classmethod
-    def from_request_errors(  # type: ignore
+    def from_request_errors(  # type: ignore[misc]
         cls,
         errors: List[CoreOpenAPIError],
         *,
-        base_loc: List[PathItem] = None,
+        base_loc: Union[List[PathItem], None] = None,
     ) -> "ValidationError":
         base_loc = ["body"] if base_loc is None else base_loc
         result = []
@@ -289,7 +292,7 @@ class ValidationError(OpenAPIError):
         )
 
     @classmethod
-    def from_response_errors(  # type: ignore
+    def from_response_errors(  # type: ignore[misc]
         cls, errors: List[CoreOpenAPIError]
     ) -> "ValidationError":
         result: List[ValidationErrorItem] = []
@@ -382,7 +385,7 @@ def get_parameter_error_details(
     loc: List[PathItem],
     err: OpenAPIParameterError,
 ) -> ValidationErrorItem:
-    parameter_name: Optional[str] = getattr(err, "name", None)
+    parameter_name: Union[str, None] = getattr(err, "name", None)
     if parameter_name is None:
         return get_common_error_details(loc, err)
 
