@@ -4,28 +4,12 @@ import os
 import warnings
 from functools import lru_cache, partial
 from pathlib import Path
-from typing import (
-    Callable,
-    cast,
-    Deque,
-    Dict,
-    List,
-    Optional,
-    overload,
-    Tuple,
-    Union,
-)
+from typing import Callable, cast, Deque, Dict, List, overload, Tuple, Union
 
 import attr
 import yaml
 from aiohttp import hdrs, web
 from aiohttp_middlewares import cors_middleware
-from aiohttp_middlewares.annotations import (
-    ExceptionType,
-    StrCollection,
-    UrlCollection,
-)
-from aiohttp_middlewares.error import Config as ErrorMiddlewareConfig
 from openapi_core.schema.specs.models import Spec
 from openapi_core.shortcuts import create_spec
 from pyrsistent import pmap
@@ -37,11 +21,15 @@ from rororo.annotations import (
     F,
     Handler,
     Protocol,
-    TypedDict,
     ViewType,
 )
 from rororo.openapi import views
-from rororo.openapi.annotations import SecurityDict, ValidateEmailKwargsDict
+from rororo.openapi.annotations import (
+    CorsMiddlewareKwargsDict,
+    ErrorMiddlewareKwargsDict,
+    SecurityDict,
+    ValidateEmailKwargsDict,
+)
 from rororo.openapi.constants import (
     APP_OPENAPI_SCHEMA_KEY,
     APP_OPENAPI_SPEC_KEY,
@@ -59,32 +47,13 @@ SchemaLoader = Callable[[bytes], DictStrAny]
 Url = Union[str, URL]
 
 
-class CorsMiddlewareKwargsDict(TypedDict, total=False):
-    allow_all: bool
-    origins: Optional[UrlCollection]
-    urls: Optional[UrlCollection]
-    expose_headers: Optional[UrlCollection]
-    allow_headers: StrCollection
-    allow_methods: StrCollection
-    allow_credentials: bool
-    max_age: Optional[int]
-
-
 class CreateSchemaAndSpec(Protocol):
     def __call__(
-        self, path: Path, *, schema_loader: SchemaLoader = None
+        self, path: Path, *, schema_loader: Union[SchemaLoader, None] = None
     ) -> Tuple[DictStrAny, Spec]:  # pragma: no cover
         ...
 
 
-class ErrorMiddlewareKwargsDict(TypedDict, total=False):
-    default_handler: Handler
-    config: Optional[ErrorMiddlewareConfig]
-    ignore_exceptions: Optional[
-        Union[ExceptionType, Tuple[ExceptionType, ...]]
-    ]
-
-
 @attr.dataclass(slots=True)
 class OperationTableDef:
     """Map OpenAPI 3 operations to aiohttp.web view handlers.
@@ -188,13 +157,13 @@ class OperationTableDef:
 
     @overload
     def register(self, handler: F) -> F:
-        ...  # pragma: no cover
+        ...
 
     @overload
     def register(self, operation_id: str) -> Callable[[F], F]:
-        ...  # pragma: no cover
+        ...
 
-    def register(self, mixed):  # type: ignore
+    def register(self, mixed):  # type: ignore[no-untyped-def]
         operation_id = mixed if isinstance(mixed, str) else mixed.__qualname__
 
         def decorator(handler: F) -> F:
@@ -202,7 +171,7 @@ class OperationTableDef:
 
             if self._is_view(handler):
                 mapping.update(
-                    self._register_view(handler, operation_id)  # type: ignore
+                    self._register_view(handler, operation_id)  # type: ignore[arg-type]
                 )
             else:
                 mapping.update(self._register_handler(handler, operation_id))
@@ -213,8 +182,7 @@ class OperationTableDef:
         return decorator(mixed) if callable(mixed) else decorator
 
     def _is_view(self, handler: F) -> bool:
-        is_class = inspect.isclass(handler)
-        return is_class and issubclass(handler, web.View)  # type: ignore
+        return inspect.isclass(handler) and issubclass(handler, web.View)
 
     def _register_handler(
         self, handler: Handler, operation_id: str
@@ -255,7 +223,10 @@ class OperationTableDef:
 
 
 def convert_operations_to_routes(
-    operations: OperationTableDef, spec: Spec, *, prefix: str = None
+    operations: OperationTableDef,
+    spec: Spec,
+    *,
+    prefix: Union[str, None] = None,
 ) -> web.RouteTableDef:
     """Convert operations table defintion to routes table definition."""
 
@@ -303,15 +274,15 @@ def convert_operations_to_routes(
 
 
 def create_schema_and_spec(
-    path: Path, *, schema_loader: SchemaLoader = None
+    path: Path, *, schema_loader: Union[SchemaLoader, None] = None
 ) -> Tuple[DictStrAny, Spec]:
     schema = read_openapi_schema(path, loader=schema_loader)
     return (schema, create_spec(schema))
 
 
 @lru_cache(maxsize=128)
-def create_schema_and_spec_with_cache(  # type: ignore
-    path: Path, *, schema_loader: SchemaLoader = None
+def create_schema_and_spec_with_cache(  # type: ignore[misc]
+    path: Path, *, schema_loader: Union[SchemaLoader, None] = None
 ) -> Tuple[DictStrAny, Spec]:
     return create_schema_and_spec(path, schema_loader=schema_loader)
 
@@ -319,8 +290,8 @@ def create_schema_and_spec_with_cache(  # type: ignore
 def find_route_prefix(
     oas: DictStrAny,
     *,
-    server_url: Union[str, URL] = None,
-    settings: BaseSettings = None,
+    server_url: Union[Url, None] = None,
+    settings: Union[BaseSettings, None] = None,
 ) -> str:
     if server_url is not None:
         return get_route_prefix(server_url)
@@ -363,7 +334,7 @@ def fix_spec_operations(spec: Spec, schema: DictStrAny) -> Spec:
     as unsecured. With missed operation security - use global security schema
     if it is defined.
     """
-    mapping: Dict[str, Optional[SecurityDict]] = {}
+    mapping: Dict[str, Union[SecurityDict, None]] = {}
 
     for path_data in schema["paths"].values():
         for maybe_operation_data in path_data.values():
@@ -402,7 +373,7 @@ def get_route_prefix(mixed: Url) -> str:
 
 
 def read_openapi_schema(
-    path: Path, *, loader: SchemaLoader = None
+    path: Path, *, loader: Union[SchemaLoader, None] = None
 ) -> DictStrAny:
     """Read OpenAPI Schema from given path.
 
@@ -437,17 +408,17 @@ def setup_openapi(
     app: web.Application,
     schema_path: Union[str, Path],
     *operations: OperationTableDef,
-    server_url: Url = None,
+    server_url: Union[Url, None] = None,
     is_validate_response: bool = True,
     has_openapi_schema_handler: bool = True,
     use_error_middleware: bool = True,
-    error_middleware_kwargs: ErrorMiddlewareKwargsDict = None,
+    error_middleware_kwargs: Union[ErrorMiddlewareKwargsDict, None] = None,
     use_cors_middleware: bool = True,
-    cors_middleware_kwargs: CorsMiddlewareKwargsDict = None,
-    schema_loader: SchemaLoader = None,
+    cors_middleware_kwargs: Union[CorsMiddlewareKwargsDict, None] = None,
+    schema_loader: Union[SchemaLoader, None] = None,
     cache_create_schema_and_spec: bool = False,
-    validate_email_kwargs: ValidateEmailKwargsDict = None,
-) -> web.Application:  # pragma: no cover
+    validate_email_kwargs: Union[ValidateEmailKwargsDict, None] = None,
+) -> web.Application:
     ...
 
 
@@ -457,34 +428,34 @@ def setup_openapi(
     *operations: OperationTableDef,
     schema: DictStrAny,
     spec: Spec,
-    server_url: Url = None,
+    server_url: Union[Url, None] = None,
     is_validate_response: bool = True,
     has_openapi_schema_handler: bool = True,
     use_error_middleware: bool = True,
-    error_middleware_kwargs: ErrorMiddlewareKwargsDict = None,
+    error_middleware_kwargs: Union[ErrorMiddlewareKwargsDict, None] = None,
     use_cors_middleware: bool = True,
-    cors_middleware_kwargs: CorsMiddlewareKwargsDict = None,
-    validate_email_kwargs: ValidateEmailKwargsDict = None,
-) -> web.Application:  # pragma: no cover
+    cors_middleware_kwargs: Union[CorsMiddlewareKwargsDict, None] = None,
+    validate_email_kwargs: Union[ValidateEmailKwargsDict, None] = None,
+) -> web.Application:
     ...
 
 
-def setup_openapi(  # type: ignore
+def setup_openapi(  # type: ignore[misc]
     app: web.Application,
-    schema_path: Union[str, Path] = None,
+    schema_path: Union[str, Path, None] = None,
     *operations: OperationTableDef,
-    schema: DictStrAny = None,
-    spec: Spec = None,
-    server_url: Url = None,
+    schema: Union[DictStrAny, None] = None,
+    spec: Union[Spec, None] = None,
+    server_url: Union[Url, None] = None,
     is_validate_response: bool = True,
     has_openapi_schema_handler: bool = True,
     use_error_middleware: bool = True,
-    error_middleware_kwargs: DictStrAny = None,
+    error_middleware_kwargs: Union[ErrorMiddlewareKwargsDict, None] = None,
     use_cors_middleware: bool = True,
-    cors_middleware_kwargs: DictStrAny = None,
-    schema_loader: SchemaLoader = None,
+    cors_middleware_kwargs: Union[CorsMiddlewareKwargsDict, None] = None,
+    schema_loader: Union[SchemaLoader, None] = None,
     cache_create_schema_and_spec: bool = False,
-    validate_email_kwargs: ValidateEmailKwargsDict = None,
+    validate_email_kwargs: Union[ValidateEmailKwargsDict, None] = None,
 ) -> web.Application:
     """Setup OpenAPI schema to use with aiohttp.web application.
 
@@ -715,7 +686,7 @@ def setup_openapi(  # type: ignore
 
         # Create the spec and put it to the application dict as well
         create_func: CreateSchemaAndSpec = (
-            create_schema_and_spec_with_cache  # type: ignore
+            create_schema_and_spec_with_cache  # type: ignore[assignment]
             if cache_create_schema_and_spec
             else create_schema_and_spec
         )
