@@ -24,34 +24,30 @@ from importlib import import_module
 from logging.config import dictConfig
 from typing import (
     Any,
+    cast,
     Collection,
     Iterator,
     MutableMapping,
-    Optional,
     Tuple,
     Type,
+    TypeVar,
     Union,
 )
 
 import environ
 from aiohttp import web
 
-from rororo.annotations import (
-    DictStrAny,
-    Level,
-    MappingStrAny,
-    MappingStrStr,
-    Settings,
-    T,
-)
+from rororo.annotations import DictStrAny, Level, MappingStrAny, Settings, T
 from rororo.logger import default_logging_dict
 from rororo.utils import ensure_collection, to_bool
 
 
 APP_SETTINGS_KEY = "settings"
 
+TBaseSettings = TypeVar("TBaseSettings", bound="BaseSettings")
 
-@environ.config(prefix=None, frozen=True)
+
+@environ.config(prefix=None, from_environ=None, frozen=True)
 class BaseSettings:
     """Base Settings data structure for configuring ``aiohttp.web`` apps.
 
@@ -91,15 +87,31 @@ class BaseSettings:
     locale: str = environ.var(name="LOCALE", default="en_US.UTF-8")
 
     # Sentry settings
-    sentry_dsn: Optional[str] = environ.var(name="SENTRY_DSN", default=None)
-    sentry_release: Optional[str] = environ.var(
+    sentry_dsn: Union[str, None] = environ.var(name="SENTRY_DSN", default=None)
+    sentry_release: Union[str, None] = environ.var(
         name="SENTRY_RELEASE", default=None
     )
 
+    @classmethod
+    def from_environ(
+        cls: Type[TBaseSettings], environment: "os._Environ[str]" = os.environ
+    ) -> TBaseSettings:
+        """Load the configuration as declared by *cls* from *environ*.
+
+        This is a typed helper, which ensures that ``Settings.from_environ()``
+        calls within typed context will not result in following mypy error::
+
+            error: "Type[Settings]" has no attribute "from_environ"  [attr-defined]
+
+        TODO: Move to ``Self`` type annotation as proposed in
+        `PEP-673 <https://peps.python.org/pep-0673/#use-in-classmethod-signatures>`_
+        """
+        return cast(TBaseSettings, environ.to_config(cls, environment))
+
     def apply(
         self,
         *,
-        loggers: Collection[str] = None,
+        loggers: Union[Collection[str], None] = None,
         remove_root_handlers: bool = False,
     ) -> None:
         """
@@ -138,11 +150,11 @@ class BaseSettings:
         return self.level == "test"
 
 
-def from_env(key: str, default: T = None) -> Union[str, Optional[T]]:
+def from_env(key: str, default: Union[T, None] = None) -> Union[str, T, None]:
     """Shortcut for safely reading environment variable.
 
     .. deprecated:: 2.0
-        Use :func:`os.getenv` instead. Will be removed in **3.0**.
+        Use :func:`os.getenv` instead. Will be removed in **4.0**.
 
     :param key: Environment var key.
     :param default:
@@ -163,7 +175,7 @@ def immutable_settings(defaults: Settings, **optionals: Any) -> MappingStrAny:
     .. deprecated:: 2.0
         Function deprecated in favor or using `attrs <https://www.attrs.org>`_
         or `dataclasses <https://docs.python.org/3/library/dataclasses.html>`_
-        for declaring settings classes. Will be removed in **3.0**.
+        for declaring settings classes. Will be removed in **4.0**.
 
     :param defaults:
        Read settings values from module or dict-like instance.
@@ -261,14 +273,14 @@ def iter_settings(mixed: Settings) -> Iterator[Tuple[str, Any]]:
 
 def setup_locale(
     lc_all: str,
-    first_weekday: int = None,
+    first_weekday: Union[int, None] = None,
     *,
-    lc_collate: str = None,
-    lc_ctype: str = None,
-    lc_messages: str = None,
-    lc_monetary: str = None,
-    lc_numeric: str = None,
-    lc_time: str = None,
+    lc_collate: Union[str, None] = None,
+    lc_ctype: Union[str, None] = None,
+    lc_messages: Union[str, None] = None,
+    lc_monetary: Union[str, None] = None,
+    lc_numeric: Union[str, None] = None,
+    lc_time: Union[str, None] = None,
 ) -> str:
     """Shortcut helper to setup locale for backend application.
 
@@ -324,7 +336,7 @@ def setup_settings(
     app: web.Application,
     settings: BaseSettings,
     *,
-    loggers: Collection[str] = None,
+    loggers: Union[Collection[str], None] = None,
     remove_root_handlers: bool = False,
 ) -> web.Application:
     """Shortcut for applying settings for given ``aiohttp.web`` app.
@@ -341,8 +353,8 @@ def setup_settings_from_environ(
     app: web.Application,
     settings_class: Type[BaseSettings],
     *,
-    environ: MappingStrStr = None,
-    loggers: Collection[str] = None,
+    environ: Union["os._Environ[str]", None] = None,
+    loggers: Union[Collection[str], None] = None,
     remove_root_handlers: bool = False,
 ) -> web.Application:
     """
@@ -356,7 +368,7 @@ def setup_settings_from_environ(
     """
     return setup_settings(
         app,
-        settings_class.from_environ(environ or os.environ),  # type: ignore
+        settings_class.from_environ(environ or os.environ),
         loggers=loggers,
         remove_root_handlers=remove_root_handlers,
     )
